@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 87 $
+# Revision: $Rev: 131 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -227,12 +227,12 @@ class AMCForm(AMCFormBase):
                 self.log.error(u"Error setting %s to %s; changing to 0", name, value)
                 self.record[name] = 0
                 self[name] = 0
-                self.modified()
+                self.onModified()
             except ValueError:
                 self.log.error(u"Cannont convert from string to integer: %s=%s", name, value)
                 self.record[name] = 0
                 self[name] = 0
-                self.modified()
+                self.onModified()
         elif (field2dateEdit.has_key(name)):
             y,m,d = Date2YMD( value )
             getattr(self, field2dateEdit[name]).setDate( QDate(y,m,d) )
