@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 109 $
+# Revision: $Rev: 128 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -35,7 +35,7 @@ from pprint import pformat
 CONFIG_TEXT = """\
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 109 $
+# Revision: $Rev: 128 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -111,6 +111,13 @@ logLevel = %(logLevel)s
 defaultPath = %(defaultPath)s
 
 
+# defaultFile defines the file to be opened by lmc when it starts up.
+# The value can either be the path to a filename or None, in which case
+# the auto-open is disabled.
+
+defaultFile = %(defaultFile)s
+
+
 # defaultMoviePath defines the path which lmc uses as its first entry
 # point when getting information from files
 # The default is the current working directory.
@@ -358,7 +365,9 @@ class _Settings0(dict):
                      'AbstractFile'          : logging.DEBUG,
                      'AMCFile33'             : logging.DEBUG,
                      'AMCForm'               : logging.INFO,
+                     'CatalogueProperties'   : logging.DEBUG,
                      'DragObject'            : logging.DEBUG,
+                     'FindDialog'            : logging.DEBUG,
                      'Interface'             : logging.DEBUG,
                      'IODeviceBuffer'        : logging.DEBUG,
                      'Language'              : logging.DEBUG,
@@ -378,6 +387,7 @@ class _Settings0(dict):
                      },
 
         'defaultPath': os.environ['PWD'],
+        'defaultFile': None,
         'defaultMoviePath': os.environ['PWD'],
         'browserPath': '/usr/bin/mozilla',
 
@@ -495,7 +505,7 @@ class _Settings0(dict):
                     'zeroPrefix_patch', 'scripts', 'defaultScript', 'autoMountPoint',
                     'ejectOnUnmount', 'defaultHistory', 'addHistoryFromRecords',
                     'recordDefault', 'autoScanAutoMountOnNew', 'autoScanOnNew',
-                    'autoScriptOnNew', 'deepcopyOnCopy']:
+                    'autoScriptOnNew', 'deepcopyOnCopy', 'defaultFile']:
             defs[key] = pformat(self[key])
 
         # class instance 
@@ -610,7 +620,7 @@ class _Pref(dict):
                     'defaultScript', 'autoMountPoint', 'ejectOnUnmount',
                     'defaultHistory', 'addHistoryFromRecords', 'recordDefault',
                     'autoScanAutoMountOnNew', 'autoScanOnNew', 'autoScriptOnNew',
-                    'deepcopyOnCopy']:
+                    'deepcopyOnCopy', 'defaultFile']:
             self[key] = deepcopy(pref[key])
 
         # debug info on a per-class basis
