@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 85 $
+# Revision: $Rev: 124 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -43,8 +43,8 @@ pref = getPreferences(__name__)
 
 class TitleMatchList(TitleMatchListBase):
     """displays title matches returned by a script"""
-    def __init__(self, parent=None, name=None, fl=0):
-        TitleMatchListBase.__init__(self, parent, name, fl)
+    def __init__(self, parent=None, name=None, modal=False, fl=0):
+        TitleMatchListBase.__init__(self, parent, name, modal, fl)
 
         self.log = logging.getLogger( self.__class__.__name__)
         self.log.setLevel(pref['logLevel'])
