@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 # Author:   $Author: merkosh $
-# Revision: $Rev: 161 $
+# Revision: $Rev: 98 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -107,9 +107,9 @@ if ($title) {
     # filter target links
     foreach (@links){
       if ((substr($_->[0], 0, 23) eq "/exec/obidos/tg/detail/") && # URL matches this prefix
-	  (ref $_->[1]->content() eq "ARRAY") &&                  # 
-	  (ref @{$_->[1]->content()}[0] ne "HTML::Element") &&    # link is clear text description
-	  (@{$_->[1]->content()}[0] !~ /buy|in\-store/i)          # link is text and does not contain "buy" and "in-store"	    
+	  ((ref @{$_->[1]->content()}[0] ne "HTML::Element") &&    # link is clear text description
+	   (@{$_->[1]->content()}[0] !~ /buy|in\-store/i)          # link is text and does not contain "buy" and "in-store"
+	   ) 
 	  ) {
 
 	$tlinks{$_->[0]} = $_->[1];		  # target link found
